#ifndef CONFIGURATIONDBDRIVER_H
#define CONFIGURATIONDBDRIVER_H

#include <QDebug>
#include <QDir>
#include <QFile>
#include <QObject>
#include <QSqlDatabase>
#include <QSqlError>
#include <QSqlQuery>
#include <QSqlRecord>
#include <QString>
#include <QVariant>

// Different ways to get list of recently changed files
//        if(dbVersion == DROPBOX_DB)
//            query = db->exec("SELECT active_server_path FROM file_journal ORDER BY active_sjid DESC LIMIT 5");
//        else if (dbVersion == CONFIG_DB)
//            query = db->exec("SELECT value FROM config WHERE key='recently_changed3'");

class ConfigurationDBDriver : public QObject
{
    Q_OBJECT
public:
    explicit ConfigurationDBDriver(QObject *parent = 0);
    ~ConfigurationDBDriver();

    QStringList listKeys() const;

    bool hasKey(const QString& key);
    QVariant getValue(const QString& key, QVariant defaultValue=QVariant());
    void setValue(const QString &key, const QVariant& value);
    void deleteValue(const QString& key);

private:
    inline QSqlQuery justQuery(const QString& query)
    {
        if(dbVersion != CONFIG_DB)
            return QSqlQuery();

        QSqlQuery result = db->exec(query);
        if(db->lastError().isValid())
            qDebug() << db->lastError() << "\nquery:" << query;
        return result;
    }
    enum DROPBOX_DB_VERSION {DROPBOX_DB, CONFIG_DB, UNKNOWN} dbVersion;
    QSqlDatabase* db;

};

#endif // CONFIGURATIONDBDRIVER_H
